@@ -2,20 +2,23 @@
 """
 cct: Module with functions related to correlated color temperature calculations
 ===============================================================================
+ These methods supersede earlier methods in cct_legacy.y (prior to Nov 2021)
 
-  :_CCT_MAX: (= 1e11 K), max. value that does not cause overflow problems. 
+ :_CCT_MAX: (= 1e11 K), max. value that does not cause overflow problems. 
  
  :_CCT_MIN: (= 550 K), min. value that does not cause underflow problems.
+ 
+ :_CCT_FALLBACK_N: Number of intervals to divide an ndarray with CCTs.
+ 
+ :_CCT_FALLBACK_UNIT: Type of scale (units) an ndarray will be subdivided.
 
  :_CCT_LUT_PATH: Folder with Look-Up-Tables (LUT) for correlated color 
                  temperature calculations. 
 
- :_CCT_LUT: Dict with LUTs structure LUT[mode][cspace][cieobs][lut i].
+ :_CCT_LUT: Dict with pre-calculated LUTs with structure LUT[mode][cspace][cieobs][lut i].
  
  :_CCT_LUT_CALC: Boolean determining whether to force LUT calculation, even if
-                 the LUT.npy files can be found in ./data/cctluts/.
-                 
- :_CCT_LUT: Dict with all pre-calculated LUTs.
+                 the LUT.pkl files can be found in ./data/cctluts/.
  
  :_CCT_LUT_RESOLUTION_REDUCTION_FACTOR: number of subdivisions when performing
                                         a cascading lut calculation to zoom-in 
@@ -26,6 +29,8 @@ cct: Module with functions related to correlated color temperature calculations
  
  :_CCT_CSPACE_KWARGS: nested dict with cspace parameters for forward and backward modes. 
  
+ :get_tcs4(): Get an ndarray of Tc's obtained from a list or tuple of tc4 4-vectors.
+ 
  :calculate_lut(): Function that calculates the LUT for the input ccts.
  
  :generate_luts(): Generate a number of luts and store them in a nested dictionary.
@@ -78,7 +83,8 @@ cct: Module with functions related to correlated color temperature calculations
                          Optics Express, 24(13), 14066–14078. 
                          <https://doi.org/10.1364/OE.24.014066>`_                        
                                 
-                                             
+ :xyz_to_cct_fibonacci(): | Calculates CCT, Duv from XYZ using a Fibonacci search method.
+                  
  :cct_to_mired(): Converts from CCT to Mired scale (or back).
  
  :xyz_to_cct_ohno2011(): Calculate cct and Duv from CIE 1931 2° xyz following Ohno (CORM 2011).
