@@ -184,6 +184,7 @@ def plot_hue_bins(hbins = 16, start_hue = 0.0, scalef = 100, \
             
         # Plot hue-bins:
         cmap = []
+        grey = (0.45,0.45,0.45) # TM30-20 recommends (166/255,166/255,166/255), but this does not provide enough contrast 
         for i in range(nhbins):
             
             # Create color from hue angle:
@@ -199,31 +200,31 @@ def plot_hue_bins(hbins = 16, start_hue = 0.0, scalef = 100, \
             
             if axtype == 'polar':
                 if plot_edge_lines == True:
-                    ax.plot(edges[:,i],r[:,i]*1.,color = 'grey',marker = 'None',linestyle = '--',linewidth = 1, markersize = 2)
+                    ax.plot(edges[:,i],r[:,i]*1.,color = grey, marker = 'None',linestyle = '--',linewidth = 0.75, markersize = 2)
                 if plot_center_lines == True:
                     if np.mod(i,2) == 1:
-                        ax.plot(theta[:,i],r[:,i],color = c,marker = None,linestyle = '--',linewidth = 1)
+                        ax.plot(theta[:,i],r[:,i],color = c,marker = None,linestyle = '--',linewidth = 0.75)
                     else:
-                        ax.plot(theta[:,i],r[:,i],color = c,marker = None,linestyle = '--',linewidth = 1,markersize = 10)
+                        ax.plot(theta[:,i],r[:,i],color = c,marker = None,linestyle = '--',linewidth = 0.75,markersize = 10)
                 if plot_bin_colors == True:
                     bar = ax.bar(dM[i],r[1,i], width = dt[i],color = c,alpha=0.25)
                 if bin_labels is not None:
-                    ax.text(hbincenters[i],1.3*scalef,bin_labels[i],fontsize = 10, horizontalalignment='center',verticalalignment='center',color = np.array([1,1,1])*0.45)
+                    ax.text(hbincenters[i],1.3*scalef,bin_labels[i],fontsize = 10, horizontalalignment='center',verticalalignment='center',color = grey)
                 if plot_axis_labels == False:
                     ax.set_xticklabels([])
                     ax.set_yticklabels([])
             else:
                 axis_ = 1.*np.array([-scalef*1.5, scalef*1.5, -scalef*1.5, scalef*1.5])
                 if plot_edge_lines == True:
-                    ax.plot(hxe[:,i],hye[:,i],color = 'grey',marker = 'None',linestyle = '--',linewidth = 1, markersize = 2)
+                    ax.plot(hxe[:,i],hye[:,i],color = grey,marker = 'None',linestyle = '--',linewidth = 0.75, markersize = 2)
 
                 if plot_center_lines == True:
                     if np.mod(i,2) == 1:
-                        ax.plot(hx[:,i],hy[:,i],color = c,marker = None,linestyle = '--',linewidth = 1)
+                        ax.plot(hx[:,i],hy[:,i],color = c,marker = None,linestyle = '--',linewidth = 0.75)
                     else:
-                        ax.plot(hx[:,i],hy[:,i],color = c,marker = None,linestyle = '--',linewidth = 1,markersize = 10)
+                        ax.plot(hx[:,i],hy[:,i],color = c,marker = None,linestyle = '--',linewidth = 0.75,markersize = 10)
                 if bin_labels is not None:
-                    ax.text(hxv[1,i],hyv[1,i],bin_labels[i],fontsize = 10,horizontalalignment='center',verticalalignment='center',color = np.array([1,1,1])*0.45)
+                    ax.text(hxv[1,i],hyv[1,i],bin_labels[i],fontsize = 10,horizontalalignment='center',verticalalignment='center',color = grey)
                 ax.axis(axis_)
                     
         if plot_axis_labels == False:
@@ -238,7 +239,7 @@ def plot_hue_bins(hbins = 16, start_hue = 0.0, scalef = 100, \
         if (axtype != 'polar') & (plot_10_20_circles == True):
             r = np.array([0.8,0.9,1.1,1.2])*scalef # plot circles at 80, 90, 100, 110, 120 % of scale f
             plotcircle(radii = r, angles = np.arange(0,365,5), color = 'w', linestyle = '-', axh = ax, linewidth = 0.5)
-            plotcircle(radii = [scalef], angles = np.arange(0,365,5), color = 'k', linestyle = '-', axh = ax, linewidth = 1)
+            plotcircle(radii = [scalef], angles = np.arange(0,365,5), color = 'k', linestyle = '-', axh = ax, linewidth = 1.25)
             ax.text(0,-0.75*scalef,'-20%',fontsize = 8,horizontalalignment='center',verticalalignment='center',color = 'w')
             ax.text(0,-1.25*scalef,'+20%',fontsize = 8,horizontalalignment='center',verticalalignment='center',color = 'w')
 
@@ -253,7 +254,7 @@ def plot_ColorVectorGraphic(jabt, jabr, hbins = 16, start_hue = 0.0, scalef = 10
                             plot_edge_lines = True, plot_center_lines = False, \
                             plot_bin_colors = True, plot_10_20_circles = True,\
                             plot_vectors = True, 
-                            gamut_line_color = 'grey',gamut_line_style = '-',
+                            gamut_line_color = None, gamut_line_style = '-',\
                             gamut_line_marker = 'o', gamut_line_label = None,\
                             axtype = 'polar', ax = None,\
                             force_CVG_layout = False,\
@@ -371,15 +372,13 @@ def plot_ColorVectorGraphic(jabt, jabr, hbins = 16, start_hue = 0.0, scalef = 10
         cmap = ['k' for i in range(hbins)]
     else:
         cmap = hvector_color_map.copy()
-        
             
     # map jabti relative to center (mean) of reference:
     if (jabti is not None) & (jabri is not None):
         jabti = (jabti - jabri)
         for i in range(hbins):
             if i in hbinnr:
-                jabti[hbinnr == i,...] = jabti[hbinnr == i,...] + jabr[i,...]
-
+                jabti[hbinnr == i,...] = jabti[hbinnr == i,...] + jabr[i,...]  
     
     if axtype == 'polar':
        
@@ -394,7 +393,7 @@ def plot_ColorVectorGraphic(jabt, jabr, hbins = 16, start_hue = 0.0, scalef = 10
         else:
             ax.plot(jabt_theta,jabt_r, color = gamut_line_color, linestyle = gamut_line_style, linewidth = 2, marker = gamut_line_marker, markersize = 4, label = gamut_line_label)
         for j in range(hbins):
-            cmap_j = [list(cmap[j])]
+            cmap_j = list(cmap[j])
             if plot_vectors == True:
                 ax.quiver(jabr_theta[j],jabr_r[j],jabt[j,1]-jabr[j,1], jabt[j,2]-jabr[j,2], edgecolor = 'k',facecolor = cmap_j, headlength=3, angles='uv', scale_units='y', scale = 2,linewidth = 0.5)
             if jabti is not None:
@@ -406,7 +405,7 @@ def plot_ColorVectorGraphic(jabt, jabr, hbins = 16, start_hue = 0.0, scalef = 10
         else:
             ax.plot(jabt[...,1],jabt[...,2], color = gamut_line_color, linestyle = gamut_line_style, linewidth = 2, marker = gamut_line_marker, markersize = 4, label = gamut_line_label)
         for j in range(hbins):
-            cmap_j = [list(cmap[j])]
+            cmap_j = list(cmap[j])
             if plot_vectors == True:
                 ax.quiver(jabr[j,1],jabr[j,2],jabt[j,1]-jabr[j,1], jabt[j,2]-jabr[j,2], color = cmap_j, headlength=3, angles='uv', scale_units='xy', scale = 1,linewidth = 0.5)
             if jabti is not None:
