@@ -50,7 +50,7 @@ import matplotlib
 from matplotlib import cm
 
 import imageio
-imageio.plugins.freeimage.download()
+
 # from skimage import exposure, img_as_uint
 
 _PATH_DATA = os.path.join(_PKG_PATH, 'toolboxes','iolidfiles','data') + _SEP
@@ -966,7 +966,20 @@ def save_texture(filename, tex, bits = 16, transpose = True):
     #im = img_as_uint(im)
     if transpose == True:
         im = im.T
-    imageio.imsave(filename, im)
+        
+    try: 
+        imageio.plugins.freeimage.download() 
+        imageio.imsave(filename, im)
+    except:
+        print("!!!      imageio.plugins.freeimage.download() failed. !!!")
+        print("!!  No image was saved. Returning 16-bit numpy ndarray !! ")
+        print("                                                          ")
+        print("  Try installing the freeimage plugin manually.") 
+        print("  or, try downgrading imageio")
+        print("  or, wait until the developers of imageio fix this.")
+        print("  or, try saving it using PIL or opencv or openexc or other.")
+        
+    return im
   
 #------------------------------------------------------------------------------
 # Make plot of LID
